VastuAngleBasedDataModel class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
VastuAngleBasedDataModel({String? direction, String? zone, String? facing, String? devta, List<
String> ? effect, String? compass_direction, double? start_angle, double? end_angle, String? element, List<String> ? remedies_primary, List<String> ? remedies_secondary}) -
VastuAngleBasedDataModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- compass_direction ↔ String?
-
getter/setter pair
- devta ↔ String?
-
getter/setter pair
- direction ↔ String?
-
getter/setter pair
-
effect
↔ List<
String> ? -
getter/setter pair
- element ↔ String?
-
getter/setter pair
- end_angle ↔ double?
-
getter/setter pair
- facing ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
remedies_primary
↔ List<
String> ? -
getter/setter pair
-
remedies_secondary
↔ List<
String> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start_angle ↔ double?
-
getter/setter pair
- zone ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Connect the generated
_$PersonToJsonfunction to thetoJsonmethod. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited