AppColor class abstract
- Implementers
Constructors
- AppColor()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- accent → const Color
- appFontColor → const Color
- appScreebBg_color → const Color
- appTextFieldLabelColor → const Color
- bg → const Color
- blueColor → const Color
- bodyTextColor → const Color
- circleAvatarBG → const Color
- highlight_black → const Color
- primary → const Color
- tabBg → const Color
- tabTextSelected → const Color
- tabTextUnSelected → const Color
- tileHeaderColorBlue → const Color
- tileHeaderColorRed → const Color
- white → const Color