Implementation
List allVastuElements = [
{
"direction": "North",
"zone": "Best",
"facing": "N1",
"devta": "Rogarkgmkrmg",
"effect": [
"Bedroom in North zone promotes prosperity",
"Bedroom in this zone promotes good helath",
"This Zone promotes peaceful sleep"
],
"compass_direction": "N",
"start_angle": 348.75,
"end_angle": 11.25,
"element": "water",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "North-Northeast (NNE)",
"zone": "Bad",
"facing": "N1",
"devta": "Rogarkgmkrmg",
"effect": [
"Bedroom in this zone cause health issues",
"Bedroom here makes immunity system weak",
""
],
"compass_direction": "NNE",
"start_angle": 11.25,
"end_angle": 33.75,
"element": "water",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "Northeast (NE)",
"zone": "Good",
"facing": "N1",
"devta": "Rogarkgmkrmg",
"effect": [
"Bedroom here brings peace and prosperity.",
"This zone is good for little children and old age people.",
"This NE Zone is not promising for young and married girls."
],
"compass_direction": "NE",
"start_angle": 33.75,
"end_angle": 56.25,
"element": "water",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "East-Northeast (ENE)",
"zone": "Good",
"facing": "N1",
"devta": "Rogarkgmkrmg",
"effect": [
"Bedroom in this Zone gives joy and happiness",
"Bedroom in ENE zone bring good news ",
"Ideal Zone for pregnant ladies"
],
"compass_direction": "ENE",
"start_angle": 56.25,
"end_angle": 78.75,
"element": "air",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "East",
"zone": "Good",
"facing": "N1",
"devta": "Rogarkgmkrmg",
"effect": [
"Bedroom here brings vitality and freshness.",
"East zone good for social connectivity",
"This Zone brings career growth."
],
"compass_direction": "E",
"start_angle": 78.75,
"end_angle": 101.25,
"element": "air",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "East-Southeast (ESE)",
"zone": "Bad",
"facing": "N1",
"devta": "Rogarkgmkrmg",
"effect": [
"ESE zone brings anxiety",
"Bedroom here give mental stress",
"This Zone causes couple disputes"
],
"compass_direction": "ESE",
"start_angle": 101.25,
"end_angle": 123.75,
"element": "air",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "Southeast (SE)",
"zone": "Bad",
"facing": "N1",
"devta": "Rogarkgmkrmg",
"effect": [
"Bedroom in SE zone cause selfish aggressive nature",
"This zone gives unrest among family members.",
"Sourth-east zone leads to instability in career."
],
"compass_direction": "SE",
"start_angle": 123.75,
"end_angle": 146.25,
"element": "fire",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "South-Southeast (SSE)",
"zone": "Good",
"effect": [
"Bedroom here helps person gain confidence",
"This Zone promotes excellent mental-physical strength.",
""
],
"compass_direction": "SSE",
"start_angle": 146.25,
"end_angle": 168.75,
"element": "fire",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "South",
"zone": "Best",
"effect": [
"Bedroom here gives calmness ",
"This Zone gives peaceful healthy sleep.",
""
],
"compass_direction": "S",
"start_angle": 168.75,
"end_angle": 191.25,
"element": "fire",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "South-Southwest (SSW)",
"zone": "Bad",
"effect": [
"Bedroom in this zone bring high expenditure",
"Bedroom here brings bodyache arthiritis",
""
],
"compass_direction": "SSW",
"start_angle": 191.25,
"end_angle": 213.75,
"element": "earth",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "Southwest (SW)",
"zone": "Good",
"effect": [
"Ideal zone for head of the family",
"ideal zone for married couples.",
"not ideal for aged people and children."
],
"compass_direction": "SW",
"start_angle": 213.75,
"end_angle": 236.25,
"element": "earth",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "West-Southwest (WSW)",
"zone": "Best",
"effect": [
"Ideal zone for peace stability in the family",
"WSW zone brings gains",
"Best Zone for Students"
],
"compass_direction": "WSW",
"start_angle": 236.25,
"end_angle": 258.75,
"element": "space(akash)",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "West",
"zone": "Good",
"effect": [
"This Zone is good for peace harmony.",
"West Zone demands watchulness about talks",
""
],
"compass_direction": "W",
"start_angle": 258.75,
"end_angle": 281.25,
"element": "space(akash)",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "West-Northwest (WNW)",
"zone": "very bad",
"effect": [
"This WNW zone gives anxiety and depression.",
"This zone brings suicidal thoughts",
"This Zone brings unknown fear-phobias"
],
"compass_direction": "WNW",
"start_angle": 281.25,
"end_angle": 303.75,
"element": "space(akash)",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "Northwest (NW)",
"zone": "Not Ideal",
"effect": [
"North-West Zone leads to emotional conflicts",
"Bedroom in NW-zone give unstable relationship.",
"This Zones gives cough-cold issues"
],
"compass_direction": "NW",
"start_angle": 303.75,
"end_angle": 326.25,
"element": "space(akash)",
"remedies_primary": [],
"remedies_secondary": []
},
{
"direction": "North-Northwest (NNW)",
"zone": "Good",
"effect": [
"Bedroom in this zone excellent for newly married ones",
"This Zone brings attraction among couples",
""
],
"compass_direction": "NNW",
"start_angle": 326.25,
"end_angle": 348.75,
"element": "water",
"remedies_primary": [],
"remedies_secondary": []
}
];